@@ -35,10 +35,7 @@ void test_wait_all()
 
         pika::wait_all_nothrow(future_array);
 
-        for (auto& f : future_array)
-        {
-            PIKA_TEST(f.is_ready());
-        }
+        for (auto& f : future_array) { PIKA_TEST(f.is_ready()); }
     }
     {
         auto f1 = make_future();
@@ -59,10 +56,7 @@ void test_wait_all()
         {
             pika::wait_all_nothrow(future_array);
 
-            for (auto& f : future_array)
-            {
-                PIKA_TEST(f.is_ready());
-            }
+            for (auto& f : future_array) { PIKA_TEST(f.is_ready()); }
         }
         catch (std::runtime_error const&)
         {
@@ -147,10 +141,7 @@ void test_wait_all_n()
 
         pika::wait_all_n_nothrow(future_array.begin(), future_array.size());
 
-        for (auto& f : future_array)
-        {
-            PIKA_TEST(f.is_ready());
-        }
+        for (auto& f : future_array) { PIKA_TEST(f.is_ready()); }
     }
     {
         std::vector<pika::future<int>> future_array;
@@ -162,10 +153,7 @@ void test_wait_all_n()
         {
             pika::wait_all_n_nothrow(future_array.begin(), future_array.size());
 
-            for (auto& f : future_array)
-            {
-                PIKA_TEST(f.is_ready());
-            }
+            for (auto& f : future_array) { PIKA_TEST(f.is_ready()); }
         }
         catch (std::runtime_error const&)
         {
