@@ -23,10 +23,7 @@ namespace pika::detail {
     void decode(std::string& str, char const* s, char const* r)
     {
         std::string::size_type pos = 0;
-        while ((pos = str.find(s, pos)) != std::string::npos)
-        {
-            str.replace(pos, 2, r);
-        }
+        while ((pos = str.find(s, pos)) != std::string::npos) { str.replace(pos, 2, r); }
     }
 
     std::string decode_string(std::string str)
@@ -45,13 +42,11 @@ namespace pika::detail {
             std::string unknown_cmd_line(ini.get_entry("pika.unknown_cmd_line", ""));
             if (!unknown_cmd_line.empty())
             {
-                std::string runtime_mode(ini.get_entry("pika.runtime_mode", ""));
                 pika::program_options::variables_map vm;
 
                 commandline_error_mode mode = commandline_error_mode::rethrow_on_error;
                 std::string allow_unknown(ini.get_entry("pika.commandline.allow_unknown", "0"));
-                if (allow_unknown != "0")
-                    mode = commandline_error_mode::allow_unregistered;
+                if (allow_unknown != "0") mode = commandline_error_mode::allow_unregistered;
 
                 std::vector<std::string> still_unregistered_options;
                 parse_commandline(
@@ -60,10 +55,7 @@ namespace pika::detail {
                 std::string still_unknown_commandline;
                 for (std::size_t i = 1; i < still_unregistered_options.size(); ++i)
                 {
-                    if (i != 1)
-                    {
-                        still_unknown_commandline += " ";
-                    }
+                    if (i != 1) { still_unknown_commandline += " "; }
                     still_unknown_commandline += enquote(still_unregistered_options[i]);
                 }
 
@@ -100,7 +92,6 @@ namespace pika::detail {
 
             if (!cmd_line.empty())
             {
-                std::string runtime_mode(ini.get_entry("pika.runtime_mode", ""));
                 pika::program_options::variables_map vm;
 
                 parse_commandline(ini, options, cmd_line, vm,
@@ -114,10 +105,7 @@ namespace pika::detail {
                     handle_print_bind(num_threads);
                 }
 
-                if (vm.count("pika:exit"))
-                {
-                    return 1;
-                }
+                if (vm.count("pika:exit")) { return 1; }
             }
         }
         catch (std::exception const& e)
