@@ -158,14 +158,14 @@ namespace pika::ensure_started_detail {
 
                 template <typename Error>
                 friend void tag_invoke(pika::execution::experimental::set_error_t,
-                    ensure_started_receiver&& r, Error&& error) noexcept
+                    ensure_started_receiver r, Error&& error) noexcept
                 {
                     r.state->v.template emplace<error_type>(error_type(PIKA_FORWARD(Error, error)));
                     r.state->set_predecessor_done();
                 }
 
                 friend void tag_invoke(pika::execution::experimental::set_stopped_t,
-                    ensure_started_receiver&& r) noexcept
+                    ensure_started_receiver r) noexcept
                 {
                     r.state->set_predecessor_done();
                 };
@@ -188,7 +188,7 @@ namespace pika::ensure_started_detail {
 
                 template <typename... Ts>
                 friend auto tag_invoke(pika::execution::experimental::set_value_t,
-                    ensure_started_receiver&& r, Ts&&... ts) noexcept
+                    ensure_started_receiver r, Ts&&... ts) noexcept
                     -> decltype(std::declval<
                                     pika::detail::variant<pika::detail::monostate, value_type>>()
                                     .template emplace<value_type>(
@@ -234,8 +234,8 @@ namespace pika::ensure_started_detail {
 
                 void operator()(error_type&& error)
                 {
-                    pika::detail::visit(error_visitor<Receiver>{PIKA_FORWARD(Receiver, receiver)},
-                        PIKA_MOVE(error));
+                    pika::detail::visit(
+                        error_visitor<Receiver>{PIKA_MOVE(receiver)}, PIKA_MOVE(error));
                 }
 
                 template <typename T,
@@ -244,8 +244,8 @@ namespace pika::ensure_started_detail {
                         std::is_same_v<std::decay_t<T>, value_type>>>
                 void operator()(T&& t)
                 {
-                    pika::detail::visit(value_visitor<Receiver>{PIKA_FORWARD(Receiver, receiver)},
-                        PIKA_FORWARD(T, t));
+                    pika::detail::visit(
+                        value_visitor<Receiver>{PIKA_MOVE(receiver)}, PIKA_FORWARD(T, t));
                 }
             };
 
@@ -297,8 +297,12 @@ namespace pika::ensure_started_detail {
 
                 if (continuation)
                 {
-                    continuation.value()();
-                    continuation.reset();
+                    // We move the continuation to a local variable to release it once the
+                    // continuation has been called. We cannot call reset on continuation after the
+                    // invocation because the shared state may already be released by the
+                    // continuation itself.
+                    auto continuation_local = PIKA_MOVE(continuation.value());
+                    continuation_local();
                 }
             }
 
