@@ -30,8 +30,7 @@ namespace pika::program_options {
           , case_insensitive(false)
         {
         }
-        basic_option(const std::string& xstring_key,
-            const std::vector<std::string>& xvalue)
+        basic_option(const std::string& xstring_key, const std::vector<std::string>& xvalue)
           : string_key(xstring_key)
           , position_key(-1)
           , value(xvalue)
