@@ -13,14 +13,14 @@ namespace pika::threads {
 
     scheduler_mode operator&(scheduler_mode sched1, scheduler_mode sched2)
     {
-        return static_cast<scheduler_mode>(static_cast<std::uint32_t>(sched1) &
-            static_cast<std::uint32_t>(sched2));
+        return static_cast<scheduler_mode>(
+            static_cast<std::uint32_t>(sched1) & static_cast<std::uint32_t>(sched2));
     }
 
     scheduler_mode operator|(scheduler_mode sched1, scheduler_mode sched2)
     {
-        return static_cast<scheduler_mode>(static_cast<std::uint32_t>(sched1) |
-            static_cast<std::uint32_t>(sched2));
+        return static_cast<scheduler_mode>(
+            static_cast<std::uint32_t>(sched1) | static_cast<std::uint32_t>(sched2));
     }
 
     scheduler_mode operator~(scheduler_mode sched)
